@@ -7,12 +7,23 @@ use Moose;
 
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome';
 
+override _build_WriteMakefile_args => sub {
+    my $self = shift;
+
+    my $args = super();
+
+    delete $args->{VERSION};
+    $args->{VERSION_FROM} = 'lib/Math/Int64.pm';
+
+    return $args;
+};
+
 override _build_WriteMakefile_dump => sub {
     my $self = shift;
 
     my $dump = super();
     $dump .= <<'EOF';
-$WriteMakefileArgs{DEFINE} = _backend_define() . q{ } . _int64_define();
+$WriteMakefileArgs{DEFINE}  = _backend_define() . q{ } . _int64_define();
 EOF
 
     return $dump;
